@@ -19,10 +19,8 @@ tocm = codata.h*codata.c/codata.e*1e2 # 12398.419739640718e-8
 
 from srxraylib.util.h5_simple_writer import H5SimpleWriter
 
-try:
-    import xraylib
-except:
-    pass
+# retrieve a bind of xraylib refractive index that accept NIST compounds
+from orangecontrib.xoppy.util.xoppy_xraylib_util import density, Refractive_Index_Re, Refractive_Index_Im
 
 class MLayer(object):
 
@@ -351,8 +349,8 @@ class MLayer(object):
         BETA = numpy.zeros(np)
         for i in range(np):  #substrate
             energy = 30e0*numpy.power(10,elfactor*(istart+i-1)) *1e-3 # in keV!!
-            delta = 1e0-xraylib.Refractive_Index_Re(matSubstrate,energy,denSubstrate)
-            beta = xraylib.Refractive_Index_Im(matSubstrate,energy,denSubstrate)
+            delta = 1e0 - Refractive_Index_Re(matSubstrate,energy,denSubstrate)
+            beta = Refractive_Index_Im(matSubstrate,energy,denSubstrate)
             DELTA[i] = delta
             BETA[i] = beta
             f.write( ("%26.17e "*2+"\n") % tuple([delta,beta]) )
@@ -363,8 +361,8 @@ class MLayer(object):
         BETA = numpy.zeros(np)
         for i in range(np): #even
             energy = 30e0*numpy.power(10,elfactor*(istart+i-1)) *1e-3 # in keV!!
-            delta = 1e0-xraylib.Refractive_Index_Re(matEven,energy,denEven)
-            beta = xraylib.Refractive_Index_Im(matEven,energy,denEven)
+            delta = 1e0 - Refractive_Index_Re(matEven,energy,denEven)
+            beta = Refractive_Index_Im(matEven,energy,denEven)
             DELTA[i] = delta
             BETA[i] = beta
             f.write( ("%26.17e  "*2+"\n") % tuple([delta,beta]) )
@@ -375,8 +373,8 @@ class MLayer(object):
         BETA = numpy.zeros(np)
         for i in range(np): #odd
             energy = 30e0*numpy.power(10,elfactor*(istart+i-1)) *1e-3 # in keV!!
-            delta = 1e0-xraylib.Refractive_Index_Re(matOdd,energy,denOdd)
-            beta = xraylib.Refractive_Index_Im(matOdd,energy,denOdd)
+            delta = 1e0 - Refractive_Index_Re(matOdd,energy,denOdd)
+            beta = Refractive_Index_Im(matOdd,energy,denOdd)
             DELTA[i] = delta
             BETA[i] = beta
             f.write( ("%26.17e "*2+"\n") % tuple([delta,beta]) )
@@ -476,26 +474,14 @@ class MLayer(object):
         pre_mlayer_dict["densityS"] = density_S
 
         if pre_mlayer_dict["densityS"] is None:
-            try:
-                pre_mlayer_dict["densityS"] = xraylib.ElementDensity(xraylib.SymbolToAtomicNumber(pre_mlayer_dict["materialS"]))
-                print("Using density for substrate (%s): %f"%(pre_mlayer_dict["materialS"],
-                      pre_mlayer_dict["densityS"]))
-            except:
-                raise Exception("Failed to load density for material: %s"%(pre_mlayer_dict["material1"]))
+            pre_mlayer_dict["densityS"] = density(pre_mlayer_dict["materialS"])
+            print("Using density for substrate (%s): %f"%(pre_mlayer_dict["materialS"], pre_mlayer_dict["densityS"]))
         if pre_mlayer_dict["density1"] is None:
-            try:
-                pre_mlayer_dict["density1"] = xraylib.ElementDensity(xraylib.SymbolToAtomicNumber(pre_mlayer_dict["material1"]))
-                print("Using density for layer 1 (even) (%s): %f" % (pre_mlayer_dict["material1"],
-                      pre_mlayer_dict["density1"]))
-            except:
-                raise Exception("Failed to load density for material: %s"%(pre_mlayer_dict["material1"]))
+            pre_mlayer_dict["density1"] = density(pre_mlayer_dict["material1"])
+            print("Using density for layer 1 (even) (%s): %f" % (pre_mlayer_dict["material1"], pre_mlayer_dict["density1"]))
         if pre_mlayer_dict["density2"] is None:
-            try:
-                pre_mlayer_dict["density2"] = xraylib.ElementDensity(xraylib.SymbolToAtomicNumber(pre_mlayer_dict["material2"]))
-                print("Using density for layer 2 (odd) (%s): %f" % (pre_mlayer_dict["material2"],
-                      pre_mlayer_dict["density2"]))
-            except:
-                raise Exception("Failed to load density for material: %s"%(pre_mlayer_dict["material2"]))
+            pre_mlayer_dict["density2"] = density(pre_mlayer_dict["material2"])
+            print("Using density for layer 2 (odd) (%s): %f" % (pre_mlayer_dict["material2"], pre_mlayer_dict["density2"]))
 
         if isinstance(pre_mlayer_dict["densityS"],str):
             pre_mlayer_dict["densityS"] = float(pre_mlayer_dict["densityS"])
@@ -769,12 +755,12 @@ class MLayer(object):
             DELO  = DELTA_O[index1] + (DELTA_O[index1+1] - DELTA_O[index1]) *(PHOT_ENER - ENER[index1])/(ENER[index1+1] - ENER[index1])
             BETO  =  BETA_O[index1] + ( BETA_O[index1+1] -  BETA_O[index1]) *(PHOT_ENER - ENER[index1])/(ENER[index1+1] - ENER[index1])
         else: # not using preprocessor, using xraylib
-            DELS  = 1.0 - xraylib.Refractive_Index_Re(self.pre_mlayer_dict["materialS"],1e-3*PHOT_ENER,self.pre_mlayer_dict["densityS"])
-            BETS  =       xraylib.Refractive_Index_Im(self.pre_mlayer_dict["materialS"],1e-3*PHOT_ENER,self.pre_mlayer_dict["densityS"])
-            DELE  = 1.0 - xraylib.Refractive_Index_Re(self.pre_mlayer_dict["material1"],1e-3*PHOT_ENER,self.pre_mlayer_dict["density1"])
-            BETE  =       xraylib.Refractive_Index_Im(self.pre_mlayer_dict["material1"],1e-3*PHOT_ENER,self.pre_mlayer_dict["density1"])
-            DELO  = 1.0 - xraylib.Refractive_Index_Re(self.pre_mlayer_dict["material2"],1e-3*PHOT_ENER,self.pre_mlayer_dict["density2"])
-            BETO  =       xraylib.Refractive_Index_Im(self.pre_mlayer_dict["material2"],1e-3*PHOT_ENER,self.pre_mlayer_dict["density2"])
+            DELS  = 1.0 - Refractive_Index_Re(self.pre_mlayer_dict["materialS"],1e-3*PHOT_ENER,self.pre_mlayer_dict["densityS"])
+            BETS  =       Refractive_Index_Im(self.pre_mlayer_dict["materialS"],1e-3*PHOT_ENER,self.pre_mlayer_dict["densityS"])
+            DELE  = 1.0 - Refractive_Index_Re(self.pre_mlayer_dict["material1"],1e-3*PHOT_ENER,self.pre_mlayer_dict["density1"])
+            BETE  =       Refractive_Index_Im(self.pre_mlayer_dict["material1"],1e-3*PHOT_ENER,self.pre_mlayer_dict["density1"])
+            DELO  = 1.0 - Refractive_Index_Re(self.pre_mlayer_dict["material2"],1e-3*PHOT_ENER,self.pre_mlayer_dict["density2"])
+            BETO  =       Refractive_Index_Im(self.pre_mlayer_dict["material2"],1e-3*PHOT_ENER,self.pre_mlayer_dict["density2"])
 
 
 
@@ -1020,6 +1006,8 @@ class MLayer(object):
         anp = numpy.abs(rp)
         return ans,anp,PHASES,PHASEP
 
+
+
 if __name__ == "__main__":
 
     from srxraylib.plot.gol import plot
@@ -1029,7 +1017,7 @@ if __name__ == "__main__":
         interactive=False,
         FILE="pre_mlayer.dat",
         E_MIN=100.0, E_MAX=500.0,
-        O_DENSITY=7.19, O_MATERIAL="Cr",  # odd: closer to vacuum
+        O_DENSITY=7.19, O_MATERIAL="Cr", #"Water, Liquid", # odd: closer to vacuum
         E_DENSITY=3.00, E_MATERIAL="Sc",  # even: closer to substrate
         S_DENSITY=2.33, S_MATERIAL="Si",  # substrate
         GRADE_DEPTH=0,
@@ -1075,4 +1063,4 @@ if __name__ == "__main__":
     # single point
     #
     a.scan(h5file="",
-            energyN=1,energy1=398.0,thetaN=1,theta1=45.0)
\ No newline at end of file
+            energyN=1,energy1=398.0,thetaN=1,theta1=45.0)
